@@ -12,8 +12,8 @@
 #' @param parse_schema boolean to enable schema defintion parsing
 #' @examples
 #' graphql2json("{ field(complex: { a: { b: [ $var ] } }) }")
-#' graphql2json("schema { query: QueryType }")
-graphql2json <- function(input, parse_schema = TRUE){
+#' graphql2json("schema { query: QueryType }", TRUE)
+graphql2json <- function(input, parse_schema = FALSE){
   stopifnot(is.character(input))
   input <- paste(input, collapse = "\n")
   json <- dump_json_ast(input, parse_schema)
